/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid library code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#ifndef _DMRAID_H_
#define _DMRAID_H_

#include <stdint.h>
#include <sys/types.h>
#include "misc/lib_context.h"
#include "display/display.h"
#include "format/format.h"
#include "log/log.h"

/*
 * Library init/exit
 */
int libdmraid_init(struct lib_context **lc, int argc, char **argv);
void libdmraid_exit(struct lib_context *lc);
struct lib_context *alloc_lib_context(char **argv);

/*
 * Retrieve version identifiers.
 */
int dm_version(char *version, size_t size);
const char *libdmraid_version(struct lib_context *lc);

/*
 * Dealing with formats.
 */
int check_valid_format(struct lib_context *lc, char *fmt);
const char *get_format_name(void *fmt);
void unregister_formats(struct lib_context *lc);

/*
 * Dealing with devices.
 */
unsigned int count_devices(struct lib_context *lc, enum dev_type type);
int discover_devices(struct lib_context *lc);
void discover_raid_devices(struct lib_context *lc, char **fmt_names, char **devices);
void discover_partitions(struct lib_context *lc);
void free_disk_infos(struct lib_context *lc);

/*
 * Erase ondisk metadata.
 */
int erase_metadata(struct lib_context *lc);

/*
 * Dealing with RAID sets.
 */
const char *get_set_type(struct lib_context *lc, void *rs);
const char *get_set_name(struct lib_context *lc, void *rs);
int build_set(struct lib_context *lc, char *name);
void process_sets(int (*func)(struct lib_context *l, void *v, int a),
		  struct lib_context *lc, int arg, int partitions);
int write_set(struct lib_context *lc, void *rs);
int activate_set(struct lib_context *lc, void *rs);
int deactivate_set(struct lib_context *lc, void *rs);
void free_sets(struct lib_context *lc);

/*
 * Memory allocation
 */
void dbg_free(void *ptr);
void *dbg_malloc(size_t size);
void *dbg_realloc(void *ptr, size_t size);
void *dbg_strdup(void *ptr);

#endif
