/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid library code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#include "internal.h"

enum rw {
	READ,
	WRITE
};

/*
 * Read/write data off/to a device.
 */
static int rw_dev(enum rw rw, char *path, void *buffer,
		  loff_t offset, size_t size)
{
	int fd, ret = 0;

	if ((fd = open(path, O_RDWR)) == -1)
		LOG_ERR(0, "Failed opening device \"%s\"\n", path);

	if (lseek64(fd, offset, SEEK_SET) == (loff_t) -1) {
		log_err("Failed seeking device \"%s\"", path);
		goto err;
	}

	if ((ret = (rw == WRITE ? write(fd, buffer, size) :
				  read(fd, buffer,size)) != size)) {
		log_err("Failed %sing %s device \"%s\"",
			rw == WRITE ? "writ" : "read",
			rw == WRITE ? "to" : "from",
			path);
		ret = 0;
		goto err;
	}

	ret = 1;

  err:
	close(fd);
	return ret;
}

/* Read data off a device. */
int read_dev(char *path, void *buffer, loff_t offset, size_t size)
{
	return rw_dev(READ, path, buffer, offset, size);
}

/* Write data to a device. */
int write_dev(char *path, void *buffer, loff_t offset, size_t size)
{
	return rw_dev(WRITE, path, buffer, offset, size);
}
