/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#ifndef	_FORMAT_H_
#define	_FORMAT_H_

enum fmt_type {
	FMT_ALL,
	FMT_RAID,
	FMT_PARTITION,
};

#  ifdef FORMAT_HANDLER

#include <sys/types.h>
#include "datastruct/list.h"

#define	to_disk	to_cpu

struct disk_info;
struct dmraid_dev;
struct dmraid_set;

struct dmraid_format {
	const char *name;	/* Format name */
	const char *descr;	/* Format description */
	enum fmt_type fmt_type;

	/*
	 * Read RAID metadata off a device and unify it.
	 */
	struct dmraid_dev* (*read)(struct lib_context *lc,
				   struct disk_info* di);

	/*
	 * Write RAID metadata to a device deunifying it
	 * or erase ondisk metadata if erase != 0.
	 */
	int (*write)(struct lib_context *lc, struct dmraid_dev* rd, int erase);

	/*
	 * Group a RAID device into a set.
	 */
	struct dmraid_set* (*group)(struct lib_context *lc,
				    struct dmraid_dev *rd);

	/*
	 * Check consistency of the RAID set metadata.
	 */
	int (*check)(struct lib_context *lc, struct dmraid_set *rs);

	/*
	 * Display RAID disk metadata native.
	 */
	void (*log)(struct lib_context *lc, struct dmraid_dev *rd);

	/*
	 * Return unified layout type of RAID device.
	 */
	enum type (*type)(struct lib_context *lc, struct dmraid_dev *rd);
};

/* Chain of registered format handlers. */
struct format_list {
	struct list_head list;
	struct dmraid_format *fmt;
};

void *alloc_meta_areas(struct dmraid_dev *rd, const char *name, unsigned int n);
void *alloc_private(const char *name, size_t size);
int check_rs(struct lib_context *lc, struct dmraid_set *rs,
	     int (*check)(struct lib_context *lc, struct dmraid_set *r));
int check_valid_format(struct lib_context *lc, char *fmt);
const char *get_format_name(void *fmt);
int register_format(struct lib_context *lc, struct dmraid_format *fmt);
int register_formats(struct lib_context *lc);
void unregister_formats(struct lib_context *lc);
void set_status(struct dmraid_set *rs, unsigned int devs,
		unsigned int operational);
int write_metadata(const char *handler, struct dmraid_dev *rd,
		   int meta_index, int erase);

#  endif

#endif
