/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#include <stdarg.h>
#include "internal.h"
#include "version.h"

static void init_cmd(struct lib_context *lc, char **argv)
{
	lc->cmd = strrchr(argv[0], '/');
	lc->cmd = lc->cmd ? lc->cmd + 1 : argv[0];
}

static void init_version(struct lib_context *lc)
{
	lc->version.text = DMRAID_LIB_VERSION;

	lc->version.v.major = DMRAID_LIB_MAJOR_VERSION;
	lc->version.v.minor = DMRAID_LIB_MINOR_VERSION;
	lc->version.v.sub_minor = DMRAID_LIB_SUBMINOR_VERSION;
	lc->version.v.suffix = DMRAID_LIB_VERSION_SUFFIX;
}

struct lib_context *alloc_lib_context(char **argv)
{
	struct lib_context *lc;

	if ((lc = dbg_malloc(sizeof(*lc)))) {
		memset(lc, 0, sizeof(*lc));
		init_cmd(lc, argv);
		init_version(lc);
		INIT_LIST_HEAD(&lc->formats);
		INIT_LIST_HEAD(&lc->disk_infos);
		INIT_LIST_HEAD(&lc->raid_devices);
		INIT_LIST_HEAD(&lc->raid_sets);
	} else
		log_err("Error allocting library context");

	return lc;
}

void free_lib_context(struct lib_context *lc)
{
	dbg_free(lc);
}
