/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#include <stdarg.h>
#include "internal.h"

/* Prompt for a yes/no answer */
int yes_no_prompt(const char *prompt, ...)
{
	int c = 0;
	va_list ap;

	while (c != 'y' && c != 'n') {
		if (c == '\n' || c == 0) {
			va_start(ap, prompt);
			vprintf(prompt, ap);
			va_end(ap);
			printf(" ? [y/n] :");
		}
		c = tolower(getchar());
	}

	while (getchar() != '\n') ;

	return (c == 'y') ? 1 : 0;
}

/* Convert a numeric string into ascii */
void mk_alpha(char *str, size_t len)
{
	char *s;
	static char asc[] = "abcdefghij";
	static char buf[2] = { '\0', '\0' };

	for (s = str; *s && len; s++, len--) {
		if (isdigit(*s)) {
			buf[0] = *s;
			*s = asc[atoi(buf)];
		}
	}
}

/* Grow a string. */
int grow_string(char **string, size_t len)
{
	char *tmp = *string;

 	len += tmp ? strlen(tmp) + 1 : 1;
	*string = dbg_realloc(*string, len);
	if (*string) {
		if (!tmp)
			**string = '\0';
	} else if (tmp)
		dbg_free(tmp);
	
	return *string ? 1 : 0;
}

/* Free a string. */
void free_string(char **string)
{
	if (*string) {
		dbg_free(*string);
		*string = NULL;
	}
}

/* Push a string onto the end of another. */
int p_str(char **string, const char *s)
{
	if (!grow_string(string, strlen(s)))
		return 0;

	strcat (*string, s);
	return 1;
}

/* Push an uint64_t in ascii onto the end of a string. */
int p_u64(char **string, uint64_t u)
{
	char buffer[32];

	sprintf(buffer, "%" PRIu64, u);
	if (!grow_string(string, strlen(buffer)))
		return 0;

	sprintf(&(*string)[strlen(*string)], "%" PRIu64, u);
	return 1;
}

