/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this dmraid code; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#ifndef	_COMMANDS_H
#define	_COMMANDS_H

/* Options actions dmraid performs. */
enum action {
	UNDEF		= 0x0,
	ACTIVATE	= 0x1,
	DEACTIVATE	= 0x2,
	FORMAT		= 0x4,
#ifndef	DMRAID_MINI
	BLOCK_DEVICES	= 0x8,
	COLUMN		= 0x10,
	DBG		= 0x20,
	DUMP		= 0x40,
	ERASE		= 0x80,
	GROUP		= 0x100,
	HELP		= 0x200,
	LIST_FORMATS	= 0x400,
#  ifdef	DMRAID_NATIVE_LOG
	NATIVE_LOG	= 0x800,
#  endif
	NO_PARTITIONS	= 0x1000,
	RAID_DEVICES	= 0x2000,
	RAID_SETS	= 0x4000,
	TEST		= 0x8000,
	VERBOSE		= 0x10000,
	ACTIVE		= 0x20000,
	INACTIVE	= 0x40000,
	VERSION		= 0x80000,
#endif
};

extern enum action action;

/*
 * Action flag definitions for set_action().
 *
 * 'Early' options can be handled directly in set_action() by calling
 * the functions registered here (set on_set member).
 */
struct lib_context;
struct actions {
	char option;		/* Char of short option */
	enum action action;	/* action flag */
	enum action needed;	/* Mandatory options or 0 if alone */
	unsigned char args;	/* Arguments allowed ? (0/1) */
	unsigned char on_set;	/* Call function when setting flag(s) (0/1) */
	/* Function to call in case of hit or NULL */
	int (*function)(struct lib_context *lc);
	enum action allowed;	/* Allowed flags (ie, other options allowed) */
};

/* Define which metadata is needed before we can call post functions. */
enum metadata {
	M_NONE	 = 0x00,
	M_DEVICE = 0x01,
	M_RAID	 = 0x02,
	M_SET	 = 0x04,
};

/* 
 * Pre and Post functions to perform for an option.
 */
struct prepost {
	enum action action;
	enum metadata metadata;
	int (*pre)(int arg);
	int arg;
	int (*post)(struct lib_context *lc, int arg);
};

int handle_args(struct lib_context *lc, int argc, char ***argv);
int perform(struct lib_context *lc, char **argv);

#endif
